@@ -34,6 +34,8 @@ class ConnectionIcon : public QObject
 Q_PROPERTY(bool connecting READ connecting NOTIFY connectingChanged)
 Q_PROPERTY(QString connectionIcon READ connectionIcon NOTIFY connectionIconChanged)
 Q_PROPERTY(QString connectionTooltipIcon READ connectionTooltipIcon NOTIFY connectionTooltipIconChanged)
+Q_PROPERTY(bool needsPortal READ needsPortal NOTIFY needsPortalChanged)
+
 Q_OBJECT
 public:
     explicit ConnectionIcon(QObject* parent = nullptr);
@@ -43,13 +45,15 @@ public:
     QString connectionIcon() const;
     QString connectionTooltipIcon() const;
 
+    bool needsPortal() const { return m_needsPortal; }
+
 private Q_SLOTS:
     void activatingConnectionChanged(const QString & connection);
     void activeConnectionAdded(const QString & activeConnection);
     void activeConnectionDestroyed();
     void activeConnectionStateChanged(NetworkManager::ActiveConnection::State state);
     void carrierChanged(bool carrier);
-    void connectivityChanged();
+    void connectivityChanged(NetworkManager::Connectivity connectivity);
     void deviceAdded(const QString & device);
     void deviceRemoved(const QString & device);
     void networkingEnabledChanged(bool enabled);
@@ -69,7 +73,7 @@ Q_SIGNALS:
     void connectingChanged(bool connecting);
     void connectionIconChanged(const QString & icon);
     void connectionTooltipIconChanged(const QString & icon);
-    void airplaneModeChanged(bool airplaneMode);
+    void needsPortalChanged(bool needsPortal);
 
 private:
     void addActiveConnection(const QString & activeConnection);
@@ -86,6 +90,7 @@ private:
     bool m_vpn;
     QString m_connectionIcon;
     QString m_connectionTooltipIcon;
+    bool m_needsPortal = false;
 
     void setDisconnectedIcon();
     void setIcons();
