@@ -31,8 +31,8 @@ Q_ENUMS(ConnectionType)
 Q_ENUMS(SecurityType)
 
 public:
-    explicit Enums(QObject* parent = 0);
-    virtual ~Enums();
+    explicit Enums(QObject* parent = nullptr);
+    ~Enums() override;
 
     enum ConnectionStatus {
         UnknownState = 0,
