@@ -28,7 +28,7 @@ class QmlPlugins : public QQmlExtensionPlugin
     Q_OBJECT
     Q_PLUGIN_METADATA(IID "org.qt-project.Qt.QQmlExtensionInterface")
     public:
-        virtual void registerTypes(const char * uri);
+        void registerTypes(const char * uri) override;
 };
 
 #endif // PLASMA_NM_QML_PLUGINS_H
