@@ -34,8 +34,8 @@ class L2tpPPPWidget : public QDialog
 {
     Q_OBJECT
 public:
-    explicit L2tpPPPWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = 0);
-    ~L2tpPPPWidget();
+    explicit L2tpPPPWidget(const NetworkManager::VpnSetting::Ptr &setting, QWidget *parent = nullptr);
+    ~L2tpPPPWidget() override;
 
     NMStringMap setting() const;
 
